==> dateutils_0.2.4.orig.tar.xz: dateutils-0.2.4/src/dexpr-parser.h <==
/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_EQ = 258,
     TOK_NE = 259,
     TOK_LT = 260,
     TOK_LE = 261,
     TOK_GT = 262,
     TOK_GE = 263,
     TOK_SPEC = 264,
     TOK_STRING = 265,
     TOK_DATETIME = 266,
     TOK_INT = 267,
     TOK_OR = 268,
     TOK_AND = 269,
     TOK_NOT = 270,
     TOK_LPAREN = 271,
     TOK_RPAREN = 272
   };
#endif
/* Tokens.  */
#define TOK_EQ 258
#define TOK_NE 259
#define TOK_LT 260
#define TOK_LE 261
#define TOK_GT 262
#define TOK_GE 263
#define TOK_SPEC 264
#define TOK_STRING 265
#define TOK_DATETIME 266
#define TOK_INT 267
#define TOK_OR 268
#define TOK_AND 269
#define TOK_NOT 270
#define TOK_LPAREN 271
#define TOK_RPAREN 272




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 83 "dexpr-parser.y"

	dexpr_t dex;
	char *sval;



/* Line 2068 of yacc.c  */
#line 91 "dexpr-parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

==> dateutils-0.4.5.tar.xz: dateutils-0.4.5/src/dexpr-parser.h <==
/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_YY_DEXPR_PARSER_H_INCLUDED
# define YY_YY_DEXPR_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    TOK_EQ = 258,
    TOK_NE = 259,
    TOK_LT = 260,
    TOK_LE = 261,
    TOK_GT = 262,
    TOK_GE = 263,
    TOK_SPEC = 264,
    TOK_STRING = 265,
    TOK_DATETIME = 266,
    TOK_INT = 267,
    TOK_OR = 268,
    TOK_AND = 269,
    TOK_NOT = 270,
    TOK_LPAREN = 271,
    TOK_RPAREN = 272
  };
#endif
/* Tokens.  */
#define TOK_EQ 258
#define TOK_NE 259
#define TOK_LT 260
#define TOK_LE 261
#define TOK_GT 262
#define TOK_GE 263
#define TOK_SPEC 264
#define TOK_STRING 265
#define TOK_DATETIME 266
#define TOK_INT 267
#define TOK_OR 268
#define TOK_AND 269
#define TOK_NOT 270
#define TOK_LPAREN 271
#define TOK_RPAREN 272

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE YYSTYPE;
union YYSTYPE
{
#line 85 "dexpr-parser.y" /* yacc.c:1909  */

	dexpr_t dex;
	char *sval;

#line 93 "dexpr-parser.h" /* yacc.c:1909  */
};
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif



int yyparse (dexpr_t *cur);

#endif /* !YY_YY_DEXPR_PARSER_H_INCLUDED  */
